@@ -8,6 +8,7 @@ from django.core.exceptions import ImproperlyConfigured
 from django.db import models, transaction
 from django.utils import timezone
 from django.utils.importlib import import_module
+from requests_oauthlib.oauth1_session import TokenRequestDenied
 from taggit.managers import TaggableManager
 
 from .exceptions import AccountLocked, LoginPasswordError
@@ -143,7 +144,7 @@ class AccessTokenManager(models.Manager):
 
             try:
                 token = self.get_token_of_class(token_class, user).get()
-            except (AccountLocked, LoginPasswordError), e:
+            except (TokenRequestDenied, AccountLocked, LoginPasswordError), e:
                 log.error(u"Error '%s' while getting new token for provider %s and user %s" % (e, provider, user))
                 user.inactivate(e)
                 continue
@@ -181,7 +182,7 @@ class AccessToken(models.Model):
     scope = JSONField(max_length=200, null=True, blank=True)
 
     # vk.com returns
-    user_id = models.PositiveIntegerField(null=True, blank=True)
+    user_id = models.BigIntegerField(null=True, blank=True)
 
     user_credentials = models.ForeignKey('UserCredentials', null=True, blank=True)
 
@@ -200,8 +201,8 @@ class UserCredentials(models.Model):
 
     name = models.CharField(max_length=100)
     provider = models.CharField(max_length=20, choices=PROVIDER_CHOICES)
-    active = models.BooleanField()
-    exception = models.TextField()
+    active = models.BooleanField(default=True)
+    exception = models.TextField(blank=True)
 
     username = models.CharField(max_length=100)
     password = models.CharField(max_length=100)
